summaryrefslogtreecommitdiffhomepage
path: root/src/raylib.h
diff options
context:
space:
mode:
authorRay <[email protected]>2021-06-17 12:47:03 +0200
committerRay <[email protected]>2021-06-17 12:47:03 +0200
commite07054d0d48161b31375ad83c6e505553bf8f204 (patch)
tree1e5e985ad3aaa000b9e734aaf96d37ad6aee0810 /src/raylib.h
parentb733e76c869afcaee1e2f716bfd99b8b10ef507c (diff)
downloadraylib-e07054d0d48161b31375ad83c6e505553bf8f204.tar.gz
raylib-e07054d0d48161b31375ad83c6e505553bf8f204.zip
RENAMED: `SwapBuffers()` -> `SwapScreenBuffer()`
Avoid possible symbol collisions
Diffstat (limited to 'src/raylib.h')
-rw-r--r--src/raylib.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/raylib.h b/src/raylib.h
index 2559a9c0..ce589bda 100644
--- a/src/raylib.h
+++ b/src/raylib.h
@@ -962,11 +962,11 @@ RLAPI const char *GetClipboardText(void); // Get clipboa
// Custom frame control functions
// NOTE: Those functions are intended for advance users that want full control over the frame processing
// By default EndDrawing() does this job: draws everything + SwapBuffers() + manage frame timming + PollInputEvents()
// To avoid that behaviour and control frame processes manually, enable in config.h: SUPPORT_CUSTOM_FRAME_CONTROL
RLAPI void InitTimer(void); // Initialize timer (hi-resolution if available)
RLAPI void WaitTime(float ms); // Wait for some milliseconds (halt program execution)
-RLAPI void SwapBuffers(void); // Swap back buffer with front buffer (screen drawing)
+RLAPI void SwapScreenBuffer(void); // Swap back buffer with front buffer (screen drawing)
RLAPI void PollInputEvents(void); // Register all input events
// Cursor-related functions
@@ -962,11 +962,11 @@ RLAPI const char *GetClipboardText(void); // Get clipboa
// Custom frame control functions
// NOTE: Those functions are intended for advance users that want full control over the frame processing
-// By default EndDrawing() does this job: draws everything + SwapBuffers() + manage frame timming + PollInputEvents()
+// By default EndDrawing() does this job: draws everything + SwapScreenBuffer() + manage frame timming + PollInputEvents()
// To avoid that behaviour and control frame processes manually, enable in config.h: SUPPORT_CUSTOM_FRAME_CONTROL
RLAPI void InitTimer(void); // Initialize timer (hi-resolution if available)